/*
 *  /MathJax/localization/ko/FontWarnings.js
 *
 *  Copyright (c) 2009-2015 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("ko","FontWarnings",{version:"2.6.0",isLoaded:true,strings:{webFont:"MathJax\uB294 \uBB38\uC11C\uC758 \uC218\uC2DD\uC744 \uD45C\uD604\uD558\uAE30 \uC704\uD574 \uC6F9 \uAE30\uBC18 \uD3F0\uD2B8\uB97C \uC0AC\uC6A9\uD569\uB2C8\uB2E4. \uB530\uB77C\uC11C, \uB2E4\uC6B4\uB85C\uB4DC \uD558\uB294\uB370 \uC2DC\uAC04\uC774 \uAC78\uB9B4 \uC218 \uC788\uACE0, \uC2DC\uC2A4\uD15C \uD3F0\uD2B8 \uD3F4\uB354\uC5D0 \uC218\uC2DD \uD3F0\uD2B8\uAC00 \uC124\uCE58\uB418\uC5B4 \uC788\uB2E4\uBA74, \uBB38\uC11C\uAC00 \uB354 \uBE68\uB9AC \uBCF4\uC5EC\uC9C8 \uAC83\uC785\uB2C8\uB2E4.",imageFonts:"MathJax\uB294 \uBB38\uC11C\uC758 \uC218\uC2DD\uC744 \uD45C\uD604\uD558\uAE30 \uC704\uD574 \uC6F9 \uAE30\uBC18 \uD3F0\uD2B8\uB97C \uC0AC\uC6A9\uD569\uB2C8\uB2E4. \uB530\uB77C\uC11C, \uD3C9\uC18C\uBCF4\uB2E4 \uB290\uB9AC\uAC8C \uBB38\uC11C\uAC00 \uBCF4\uC5EC\uC9C8 \uC218\uB3C4 \uC788\uC73C\uBA70, \uD504\uB9B0\uD130\uC5D0\uC11C \uCD5C\uB300 \uD574\uC0C1\uB3C4\uB85C \uC218\uC2DD\uC744 \uC778\uC1C4\uD558\uC9C0 \uBABB\uD560 \uC218 \uC788\uC2B5\uB2C8\uB2E4.",webFonts:"\uB300\uBD80\uBD84\uC758 \uCD5C\uC2E0 \uBE0C\uB77C\uC6B0\uC800\uB4E4\uC740 \uC6F9\uC5D0\uC11C \uD3F0\uD2B8\uB97C \uB2E4\uC6B4\uB85C\uB4DC \uBC1B\uB294 \uAC83\uC774 \uAC00\uB2A5\uD569\uB2C8\uB2E4. \uCD5C\uC2E0 \uBC84\uC804\uC758 \uBE0C\uB77C\uC6B0\uC800\uB85C \uC5C5\uB370\uC774\uD2B8(\uB610\uB294 \uBE0C\uB77C\uC6B0\uC800 \uBCC0\uACBD)\uD558\uBA74 \uC774 \uBB38\uC11C\uC758 \uC218\uC2DD\uC774 \uB354 \uC798 \uBCF4\uC77C \uC218 \uC788\uC2B5\uB2C8\uB2E4."}});MathJax.Ajax.loadComplete("[MathJax]/localization/ko/FontWarnings.js");
